.. DBXS documentation master file, created by
   sphinx-quickstart on Tue Aug  8 00:06:45 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root toctree directive.

DataBase Acc(X)esS
================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   introduction
   howto


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
